From d9bcf68e395d6156645a7974b1a992aa6e6c00aa Mon Sep 17 00:00:00 2001
From: Marius Cramer <m.cramer@pixcept.de>
Date: Mon, 14 Oct 2013 08:57:25 -0400
Subject: [PATCH] Added missing empty directories from svn import

---
 install/install.php |    8 ++++++--
 1 files changed, 6 insertions(+), 2 deletions(-)

diff --git a/install/install.php b/install/install.php
index a3b5708..adb1db5 100644
--- a/install/install.php
+++ b/install/install.php
@@ -34,6 +34,8 @@
 
 error_reporting(E_ALL|E_STRICT);
 
+define('INSTALLER_RUN', true);
+
 //** The banner on the command line
 echo "\n\n".str_repeat('-',80)."\n";
 echo " _____ ___________   _____              __ _         ____
@@ -106,8 +108,9 @@
 $conf['language'] = $inst->simple_query('Select language', array('en','de'), 'en');
 $conf['timezone'] = get_system_timezone();
 
 //* Set defaukt theme
 $conf['theme'] = 'default';
+$conf['language_file_import_enabled'] = true;
 
 //** Select installation mode
 $install_mode = $inst->simple_query('Installation mode', array('standard','expert'), 'standard');
@@ -565,7 +568,8 @@
 	}*/
 	
 	//** Configure ISPConfig :-)
-	if(strtolower($inst->simple_query('Install ISPConfig Web Interface',array('y','n'),'y')) == 'y') {
+	$install_ispconfig_interface_default = ($conf['mysql']['master_slave_setup'] == 'y')?'n':'y';
+	if(strtolower($inst->simple_query('Install ISPConfig Web Interface',array('y','n'),$install_ispconfig_interface_default)) == 'y') {
 		swriteln('Installing ISPConfig');
 		
 		//** We want to check if the server is a module or cgi based php enabled server
@@ -106,8 +108,9 @@
 $conf['timezone'] = get_system_timezone();
 
-//* Set defaukt theme
+//* Set default theme
 $conf['theme'] = 'default';

--
Gitblit v1.9.1